#Generate a series of R scripts to run EEMD in parallel
#along with a shell script to execute them
#using the BSUB parallel manager

trials <- 500 #Number of EEMD trials
trials.per.script <- 1 #Trials per core
dir.create("parallel_r_scripts")

for(t in seq_len(trials/trials.per.script)) {

    script.code <- paste(
        "library(hht)",
        "load(\"tremor.RData\")",
        "sig <- tremor$sig",
        "dt <- tremor$dt", 
        "tt <- seq_len(length(sig)) * dt",
        "noisy <- sig[(1):(20/dt)]",
        "noisy <- noisy-mean(noisy)",
        "noise.amp <- max(abs(noisy))",
        paste("trials <- ", trials.per.script, sep = ""),
        "nimf <- 15",
        paste("trials.dir <- \"/netscr/haksaeng/hht/batch_", sprintf("%04d", t), "\"", sep = ""),
        "EEMD(sig, tt, noise.amp, trials, nimf, trials.dir = trials.dir, tol = 3, max.sift = 100)", 
        sep = "\n")
       
    sh.script <- paste(
        "bsub -q day -o ",
        "parallel_r_scripts/script_",
        sprintf("%04d", t),
        ".R.log ",
        "\"R CMD BATCH --vanilla ",
        "parallel_r_scripts/script_", sprintf("%04d", t), ".R\"\n",
        sep = "") 
    cat(script.code, file = paste("parallel_r_scripts/script_", sprintf("%04d", t), ".R", sep = "")) 
    cat(sh.script, file = "run_parallel_EEMD.sh", append = TRUE)
}

in.dirs <- list.files(include.dirs = TRUE, pattern = "batch_\\d{4}")
out.dir <- "tremor_eemd"
CombineTrials(in.dirs, out.dir)

